@@ -1,5 +1,7 @@
 """Filterstest for Property Filtering."""
 
+import logging
+
 from django.db import models
 
 from django_filters import Filter, FilterSet
@@ -8,8 +10,7 @@ from django_property_filter.constants import EMPTY_VALUES
 from django_property_filter.filters import EXPLICIT_ONLY_FILTERS, PRESERVE_ORDER_FILTERS, PropertyBaseFilter
 from django_property_filter.utils import filter_qs_by_pk_list
 
-
-KEEP_ORDER_FILTER = []
+logger = logging.getLogger(__name__)
 
 
 class PropertyFilterSet(FilterSet):
@@ -29,6 +30,8 @@ class PropertyFilterSet(FilterSet):
             if isinstance(self.filters[name], PropertyBaseFilter):
                 property_filter_list.append((name, value))
             else:
+                logger.debug(F'Filtering value "{value}" with Filter: "{self.filters[name].__class__.__name__}", '
+                             F'DATA: "{self.filters[name].__dict__}"')
                 queryset = self.filters[name].filter(queryset, value)
                 assert isinstance(  # Assert taken from parent function #nosec
                     queryset, models.QuerySet), \
@@ -45,14 +48,20 @@ class PropertyFilterSet(FilterSet):
             if queryset.ordered:
                 preserve_order = list(qs_pk_list)
 
+            logger.debug(F'pk_list after normal Filter Filtering {pk_list}')
+
             for name, value in property_filter_list:
                 if value not in EMPTY_VALUES:
+                    logger.debug(F'Filtering pk_list against value "{value}" with Property Filter: '
+                                 F'"{self.filters[name].__class__.__name__}", DATA: "{self.filters[name].__dict__}"')
                     pk_list = self.filters[name].filter_pks(pk_list, queryset, value)
+                    logger.debug(F'>>> Resulting pk_list {pk_list}')
 
                     # If we need to preserve order keep track of the latest order list
                     if self.filters[name].__class__ in PRESERVE_ORDER_FILTERS:
                         preserve_order = pk_list.copy()
 
+            logger.debug('Filtering Property Filter queryset')
             queryset = filter_qs_by_pk_list(queryset, pk_list, preserve_order=preserve_order)
 
         return queryset
