@@ -6,6 +6,7 @@ import sqlite3
 
 from functools import reduce
 from operator import or_
+from distutils.util import strtobool
 
 from django.db import connection
 from django.db.models import Case, When, Q
@@ -53,7 +54,7 @@ def convert_int_list_to_range_lists(int_list, *, sort_list=True):
 
 
 def get_max_params_for_db():
-    """Get the allowed number of maximum parameters for the database used, ot None if no limit."""
+    """Get the allowed number of maximum parameters for the database used, or None if no limit."""
     max_params = None
 
     if 'USER_DB_MAX_PARAMS' in os.environ:
@@ -64,13 +65,7 @@ def get_max_params_for_db():
             logging.error(F'Invalid Environment Variable "USER_DB_MAX_PARAMS", int expected but got "{user_limit}".')
 
     if max_params is None and get_db_vendor() == 'sqlite':
-        # Bit of a hack but should work for sqlite rather than using a dependancy like "packaging" package
-        major, minor, _ = get_db_version().split('.')
-        # Limit was increased from version 3.32.0 onwards
-        if (int(major) > 3) or (int(major) == 3 and int(minor) >= 32):
-            max_params = 32766
-        else:
-            max_params = 999
+        max_params = 999
 
     return max_params
 
@@ -160,7 +155,7 @@ def filter_qs_by_pk_list(queryset, pk_list, *, preserve_order=None):
                 result_qs = queryset.filter(range_filter_expr)
 
             logging.warning(F'Only returning the first {result_qs.count()} items because of max parameter '
-                            F'limitations of Database "{get_db_vendor()}" with version "{get_db_version()}"')
+                            F'limitations of Database "{get_db_vendor()}"')
 
     if preserve_order:
         preserved = Case(*[When(pk=pk, then=pos) for pos, pk in enumerate(preserve_order)])
@@ -263,4 +258,15 @@ def compare_by_lookup_expression(  # pylint: disable=too-many-branches,too-many-
         if property_value:
             result = property_value.stop == lookup_value
 
+    logging.debug(F'property value: "{property_value}", expr: "{lookup_expr}", value: '
+                  F'"{lookup_value}" ({type(lookup_value)}) ({type(property_value)}), result: "{result}"')
+
     return result
+
+
+def convert_value_to_type(target_type, value):
+    """Convert the given value to the given type, return the value if can't convert."""
+    if (target_type == bool) and (isinstance(value, str)):
+        return bool(strtobool(value))
+
+    return target_type(value)
